/*
 * Copyright (C) 2008 Carl Worth
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/ .
 *
 * Author: Carl Worth <cworth@cworth.org>
 */

#include "loudgame.h"

#include <string.h>
#include <stdlib.h>

static void
echo_handle_message (loudgame_t *lg,
		     const char	*peer,
		     const char	*message)
{
    LmMessage *reply;
    gboolean result;
    GError *error = NULL;

    reply = lm_message_new (peer, LM_MESSAGE_TYPE_MESSAGE);

    lm_message_node_add_child (reply->node, "body", message);

    result = lm_connection_send (lg->connection, reply, &error);
    lm_message_unref (reply);

    if (! result) {
	g_error ("lm_connection_send failed: error->message");
	loudgame_quit (lg, 1);
    }
}

int
main (int argc, char **argv)
{
    loudgame_t lg;

    loudgame_init (&lg, argc, argv);

    lg.handle_message = echo_handle_message;

    return loudgame_run (&lg);
}
